Discover Packages
codeberg.org/clambin/homewizard-cli
internal
cmd
users
package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Apr 23, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type AddCmd struct {
UserName string `arg:"" help:"Name of user to add"`
Interval time .Duration `short:"i" default:"10s" help:"Interval for user creation"`
}
type Cmd struct {
List ListCmd `cmd:"" help:"List users"`
Delete DeleteCmd `cmd:"" help:"Delete user"`
Add AddCmd `cmd:"" help:"Add user"`
}
type DeleteCmd struct {
UserName string `arg:"" help:"Name of user to delete"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.